/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_cg_it.c
* Version      : 
* Device(s)    : R5F117GCG
* Tool-Chain   : IAR Systems iccrl78
* Description  : This file implements device driver for IT module.
* Creation Date: 10/01/2015
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_it.h"
/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_IT_Create
* Description  : This function initializes the IT module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT_Create(void)
{
    TMKAEN = 1U;                         /* supply IT clock */
    ITMC = _0000_IT_OPERATION_DISABLE;   /* disable IT operation */
    TMKAMK = 1U;                         /* disable INTIT interrupt */
    TMKAIF = 0U;                         /* clear INTIT interrupt flag */
    /* Set INTIT low priority */
    TMKAPR1 = 1U;                        /* set INTIT interrupt priority */
    TMKAPR0 = 1U;                        /* set INTIT interrupt priority */
    PRR2 = 0x80;                         /* 12-bit timer reset state */
    ITMC = _0CCC_ITMCMP_VALUE;

    TRTCR0 = 0x10;                       /* operates as two 8 bit counter and supply clock */
    TRTMD0 = 0x00;                       /* Fsxr for both counter */
    TRTCMP00  = 22;                      /* 671uS for low power op-amp stabilization time */

    TRTCR1 = 0x90;                       /* operates as 16 bit counter and supply clock */
    TRTMD1 = 0x05;                       /* Fsxr/32 for counter */
    TRTCMP1  = 2047;                     /* Wake up MCU every 2s.*/
}

/***********************************************************************************************************************
* Function Name: R_IT_Start
* Description  : This function starts IT module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT_Start(void)
{
    PRR2 = 0x00;                        /* 12-bit timer reset release */
    TMKAIF = 0U;                        /* clear INTIT interrupt flag  */
    TMKAMK = 0U;                        /* enable INTIT interrupt  */
    ITMC |= _8000_IT_OPERATION_ENABLE;  /* enable IT operation */
}

/***********************************************************************************************************************
* Function Name: R_IT_Stop
* Description  : This function stops IT module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT_Stop(void)
{
    TMKAMK = 0U;                                    /* disable INTIT interrupt  */
    TMKAIF = 0U;                                    /* clear INTIT interrupt flag  */  
    PRR2 = 0x80;                                    /* 12-bit timer reset state */
    ITMC &= (uint16_t)~_8000_IT_OPERATION_ENABLE;   /* disable IT operation */    
}

/***********************************************************************************************************************
* Function Name: R_IT00_Start
* Description  : This function starts IT00 module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT00_Start(void)
{
    ITIF00 = 0U;
    ITMK00 = 0U;
    TSTART00 = 1U;
}

/***********************************************************************************************************************
* Function Name: R_IT00_Stop
* Description  : This function stops IT00 module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT00_Stop(void)
{
    ITMK00 = 1U;
    ITIF00 = 0U;
    TSTART00 = 0;
}

/***********************************************************************************************************************
* Function Name: R_IT10_Start
* Description  : This function starts IT10 module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT10_Start(void)
{
    ITIF10 = 0U;
    ITMK10 = 0U;
    TSTART10 = 1;

}

/***********************************************************************************************************************
* Function Name: R_IT10_Stop
* Description  : This function stops IT10 module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_IT10_Stop(void)
{
    ITMK10 = 1U;
    ITIF10 = 0U;
    TSTART10 = 0;
}
/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
