/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : user_main.c
* Version      : 
* Device(s)    : R5F117GCG
* Tool-Chain   : IAR Systems iccrl78
* Description  : This file implements main function.
* Creation Date: 10/01/2015
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_cgc.h"
#include "r_cg_port.h"
#include "r_cg_serial.h"
#include "r_cg_adc.h"
#include "r_cg_wdt.h"
#include "r_cg_it.h"
#include "r_cg_rtc.h"
#include "r_cg_amp.h"
#include "r_cg_cmp.h"
#include "r_cg_pclbuz.h"
/* Start user code for include. Do not edit comment generated here */
#include <stdio.h>
#define BUZZER_ENABLE
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
uint16_t	startup_timer;
uint16_t	buzzer_timer;
uint8_t		buzzer_state;
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: user_main
* Description  : This function implements main function.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void user_main(void)
{
    SENSOR_PWROFF = 0;
    R_RTC_Start();
    buzzer_state = BUZZER_IDLE;
    AMP_LPF_Start();
    startup_timer = g1secTick;

#if 1
    while(g1secTick - startup_timer  < 10)
#else
    while(amp_state != AMP_STATE_OPERATING)
#endif
    {                       /* Wait for opamp to be stablized */
    	STOP();
    }
   
    while (1U) {
        STOP();

#ifdef BUZZER_ENABLE
        switch(buzzer_state) 
        {
            case  BUZZER_IDLE:
                // OUT1 = !OUT1;    // set OUT1 to 1 will increase AMP0o signal.
                R_ADC_Set_OperationOn();
                ADS = ADCHANNEL7;           // AMP1O
                adc_state = ADC_BIAS;
                R_ADC_Start();
                while(adc_state != ADC_DONE)
                {
                    // Wait for ADC convertion to finish.
                    HALT();
                };
                if((adc_co > (adc_bias + adc_adiss / 11))) /* CO concentration > 100PPM */
                {
                    R_PCLBUZ1_Start(); 
            	    buzzer_state = BUZZER_ON;
            	    buzzer_timer = g1secTick;
                } 
                break;
            case  BUZZER_ON:
                if(g1secTick - buzzer_timer > 3) 
    	        {   // Sound buzzer for 4 second.
        	        buzzer_timer = g1secTick;
        	        buzzer_state = BUZZER_OFF;
        	        R_PCLBUZ1_Stop(); 
                }
                break;
            case  BUZZER_OFF:
        	    if(g1secTick - buzzer_timer > 0) 
        	    {   // wait for one second for opamp circuit to be stable
        	        buzzer_timer = g1secTick;
        	        buzzer_state = BUZZER_IDLE;
        	    }
        	    break;
        }
#endif  // BUZZER_ENABLE		  
    }
}
